.. image:: /static/logo.png

|

Python-Arango
-------------

Welcome to the documentation for **python-arango**, a Python driver for ArangoDB_.

Requirements
=============

- ArangoDB version 3.7+
- Python version 3.7+

Installation
============

.. code-block:: bash

    ~$ pip install python-arango --upgrade

Contents
========

.. toctree::
    :maxdepth: 1

    overview
    database
    collection
    document
    schema
    indexes
    graph
    aql
    simple
    cursor
    async
    batch
    transaction
    admin
    user
    task
    wal
    pregel
    foxx
    view
    analyzer
    threading
    errors
    logging
    auth
    http
    replication
    cluster
    serializer
    backup
    errno
    contributing
    specs

.. _ArangoDB: https://www.arangodb.com
